@@ -66,6 +66,11 @@ protected:
 	virtual void update(void);
 
 public:
+	/**
+	 * Size of date string field.
+	 */
+	static const size_t sz_string;
+
 	/**
 	 * Create a julian date from a time_t type.
 	 * @param value from time()
@@ -320,6 +325,11 @@ protected:
 	virtual void update(void);
 
 public:
+	/**
+	 * Size of time string field.
+	 */
+	static const size_t sz_string;
+
 	/**
 	 * Create a time from the time portion of a time_t.
 	 * @param value of time_t to use.
@@ -562,6 +572,11 @@ public:
 	 */
 	static const long c_week;
 
+	/**
+	 * Size of datetime string field.
+	 */
+	static const size_t sz_string;
+
 	/**
 	 * Construct a date and time from C libraray time_t type.		
 	 * @param time type to make date and time from.
